Processor.App.OutStreamer.stream\_to\_file.OutStreamerFileHTMLContent.metadata\_to\_string
==========================================================================================

.. currentmodule:: Processor.App.OutStreamer.stream_to_file

.. automethod:: OutStreamerFileHTMLContent.metadata_to_string